pub struct OrderedF32(/* private fields */);Expand description
A wrapper around f32 that provides total ordering by rejecting NaN values. This type is sortable and can be used in collections that require Ord, such as BTreeMap and BTreeSet. It prevents NaN values from being stored, ensuring that all values are comparable and can be sorted consistently.
Implementations
Sourceimpl OrderedF32
impl OrderedF32
Methods from Deref<Target = f32>
pub const RADIX: u32 = 2
pub const BITS: u32 = 32
pub const MANTISSA_DIGITS: u32 = 24
pub const DIGITS: u32 = 6
pub const EPSILON: f32 = 1.19209290e-07_f32
pub const MIN: f32 = -3.40282347e+38_f32
pub const MIN_POSITIVE: f32 = 1.17549435e-38_f32
pub const MAX: f32 = 3.40282347e+38_f32
pub const MIN_EXP: i32 = -125
pub const MAX_EXP: i32 = 128
pub const MIN_10_EXP: i32 = -37
pub const MAX_10_EXP: i32 = 38
pub const NAN: f32
pub const INFINITY: f32
pub const NEG_INFINITY: f32
pub const MAX_EXACT_INTEGER: i32
pub const MIN_EXACT_INTEGER: i32
1.62.0 · Sourcepub fn total_cmp(&self, other: &f32) -> Ordering
pub fn total_cmp(&self, other: &f32) -> Ordering
Returns the ordering between self and other.
Unlike the standard partial comparison between floating point numbers,
this comparison always produces an ordering in accordance to
the totalOrder predicate as defined in the IEEE 754 (2008 revision)
floating point standard. The values are ordered in the following sequence:
- negative quiet NaN
- negative signaling NaN
- negative infinity
- negative numbers
- negative subnormal numbers
- negative zero
- positive zero
- positive subnormal numbers
- positive numbers
- positive infinity
- positive signaling NaN
- positive quiet NaN.
The ordering established by this function does not always agree with the
PartialOrd and PartialEq implementations of f32. For example,
they consider negative and positive zero equal, while total_cmp
doesn’t.
The interpretation of the signaling NaN bit follows the definition in the IEEE 754 standard, which may not match the interpretation by some of the older, non-conformant (e.g. MIPS) hardware implementations.
Example
struct GoodBoy {
name: String,
weight: f32,
}
let mut bois = vec![
GoodBoy { name: "Pucci".to_owned(), weight: 0.1 },
GoodBoy { name: "Woofer".to_owned(), weight: 99.0 },
GoodBoy { name: "Yapper".to_owned(), weight: 10.0 },
GoodBoy { name: "Chonk".to_owned(), weight: f32::INFINITY },
GoodBoy { name: "Abs. Unit".to_owned(), weight: f32::NAN },
GoodBoy { name: "Floaty".to_owned(), weight: -5.0 },
];
bois.sort_by(|a, b| a.weight.total_cmp(&b.weight));
// `f32::NAN` could be positive or negative, which will affect the sort order.
if f32::NAN.is_sign_negative() {
assert!(bois.into_iter().map(|b| b.weight)
.zip([f32::NAN, -5.0, 0.1, 10.0, 99.0, f32::INFINITY].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
} else {
assert!(bois.into_iter().map(|b| b.weight)
.zip([-5.0, 0.1, 10.0, 99.0, f32::INFINITY, f32::NAN].iter())
.all(|(a, b)| a.to_bits() == b.to_bits()))
}Trait Implementations
Sourceimpl Clone for OrderedF32
impl Clone for OrderedF32
Sourcefn clone(&self) -> OrderedF32
fn clone(&self) -> OrderedF32
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for OrderedF32
impl Debug for OrderedF32
Sourceimpl Default for OrderedF32
impl Default for OrderedF32
Sourcefn default() -> OrderedF32
fn default() -> OrderedF32
Sourceimpl Deref for OrderedF32
impl Deref for OrderedF32
Sourceimpl<'de> Deserialize<'de> for OrderedF32
impl<'de> Deserialize<'de> for OrderedF32
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<OrderedF32, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<OrderedF32, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl Display for OrderedF32
impl Display for OrderedF32
Sourceimpl From<OrderedF32> for f32
impl From<OrderedF32> for f32
Sourcefn from(v: OrderedF32) -> f32
fn from(v: OrderedF32) -> f32
Sourceimpl Hash for OrderedF32
impl Hash for OrderedF32
Sourceimpl IntoValue for OrderedF32
impl IntoValue for OrderedF32
fn into_value(self) -> Value
Sourceimpl Ord for OrderedF32
impl Ord for OrderedF32
Sourcefn cmp(&self, other: &OrderedF32) -> Ordering
fn cmp(&self, other: &OrderedF32) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for OrderedF32
impl PartialEq for OrderedF32
Sourceimpl PartialOrd for OrderedF32
impl PartialOrd for OrderedF32
Sourceimpl Serialize for OrderedF32
impl Serialize for OrderedF32
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Sourceimpl TryFrom<f32> for OrderedF32
impl TryFrom<f32> for OrderedF32
Sourceimpl TryFromValue for OrderedF32
impl TryFromValue for OrderedF32
Sourcefn try_from_value(value: &Value) -> Result<OrderedF32, FromValueError>
fn try_from_value(value: &Value) -> Result<OrderedF32, FromValueError>
impl Copy for OrderedF32
impl Eq for OrderedF32