Struct ResponseMessage
Source pub struct ResponseMessage {
pub request_id: String,
pub response: Result<ChannelResponse, Error>,
pub timestamp: Instant,
}
Response message for channel sessions (WebSocket-specific)
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.